# mrms-data

https://github.com/user-attachments/assets/56616688-86d4-46a5-9fc9-e23e58149e65

Convenience tools for reading and processing MRMS data.

_____________

**Installation**

```sh
pip install emaremes
```


